from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.create_saved_search_body_search_params_type_0_company_search_params_job_posting_stats_type_0_none_of_type_0_item_type_5_location_type import CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5LocationType
from ..models.create_saved_search_body_search_params_type_0_company_search_params_job_posting_stats_type_0_none_of_type_0_item_type_5_rule import CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5Rule
from typing import cast
from typing import cast, Union

if TYPE_CHECKING:
  from ..models.create_saved_search_body_search_params_type_0_company_search_params_job_posting_stats_type_0_none_of_type_0_item_type_5_range_type_1 import CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5RangeType1
  from ..models.create_saved_search_body_search_params_type_0_company_search_params_job_posting_stats_type_0_none_of_type_0_item_type_5_range_type_0 import CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5RangeType0





T = TypeVar("T", bound="CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5")



@_attrs_define
class CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5:
    """ 
        Attributes:
            rule (CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5Rule):
            location_type
                (CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5LocationType):
            range_ (Union['CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5
                RangeType0',
                'CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5RangeType1']):
     """

    rule: CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5Rule
    location_type: CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5LocationType
    range_: Union['CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5RangeType0', 'CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5RangeType1']
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.create_saved_search_body_search_params_type_0_company_search_params_job_posting_stats_type_0_none_of_type_0_item_type_5_range_type_1 import CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5RangeType1
        from ..models.create_saved_search_body_search_params_type_0_company_search_params_job_posting_stats_type_0_none_of_type_0_item_type_5_range_type_0 import CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5RangeType0
        rule = self.rule.value

        location_type = self.location_type.value

        range_: dict[str, Any]
        if isinstance(self.range_, CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5RangeType0):
            range_ = self.range_.to_dict()
        else:
            range_ = self.range_.to_dict()



        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "rule": rule,
            "locationType": location_type,
            "range": range_,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.create_saved_search_body_search_params_type_0_company_search_params_job_posting_stats_type_0_none_of_type_0_item_type_5_range_type_1 import CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5RangeType1
        from ..models.create_saved_search_body_search_params_type_0_company_search_params_job_posting_stats_type_0_none_of_type_0_item_type_5_range_type_0 import CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5RangeType0
        d = dict(src_dict)
        rule = CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5Rule(d.pop("rule"))




        location_type = CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5LocationType(d.pop("locationType"))




        def _parse_range_(data: object) -> Union['CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5RangeType0', 'CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5RangeType1']:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                range_type_0 = CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5RangeType0.from_dict(data)



                return range_type_0
            except: # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            range_type_1 = CreateSavedSearchBodySearchParamsType0CompanySearchParamsJobPostingStatsType0NoneOfType0ItemType5RangeType1.from_dict(data)



            return range_type_1

        range_ = _parse_range_(d.pop("range"))


        create_saved_search_body_search_params_type_0_company_search_params_job_posting_stats_type_0_none_of_type_0_item_type_5 = cls(
            rule=rule,
            location_type=location_type,
            range_=range_,
        )


        create_saved_search_body_search_params_type_0_company_search_params_job_posting_stats_type_0_none_of_type_0_item_type_5.additional_properties = d
        return create_saved_search_body_search_params_type_0_company_search_params_job_posting_stats_type_0_none_of_type_0_item_type_5

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class SyncCombinedSearchBodyCompanyParamsJobPostingsV2Type0AnyOfType0ItemGeoLocationType0RadiusType1Unit(str, Enum):
    KILOMETERS = "kilometers"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.investment_search_body_search_params_type_0 import InvestmentSearchBodySearchParamsType0





T = TypeVar("T", bound="InvestmentSearchBody")



@_attrs_define
class InvestmentSearchBody:
    """ 
        Attributes:
            api_key (str): Your Fiber API key
            search_params (Union['InvestmentSearchBodySearchParamsType0', None, Unset]): Investment search filter
                parameters. If not provided, returns all investments (subject to pagination)
            page_size (Union[Unset, int]): Number of investments to return per page (max 100) Default: 25.
            cursor (Union[None, Unset, str]): Pagination cursor returned from a previous search response. Use this to fetch
                the next page of results. Null for the first page.
     """

    api_key: str
    search_params: Union['InvestmentSearchBodySearchParamsType0', None, Unset] = UNSET
    page_size: Union[Unset, int] = 25
    cursor: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.investment_search_body_search_params_type_0 import InvestmentSearchBodySearchParamsType0
        api_key = self.api_key

        search_params: Union[None, Unset, dict[str, Any]]
        if isinstance(self.search_params, Unset):
            search_params = UNSET
        elif isinstance(self.search_params, InvestmentSearchBodySearchParamsType0):
            search_params = self.search_params.to_dict()
        else:
            search_params = self.search_params

        page_size = self.page_size

        cursor: Union[None, Unset, str]
        if isinstance(self.cursor, Unset):
            cursor = UNSET
        else:
            cursor = self.cursor


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "apiKey": api_key,
        })
        if search_params is not UNSET:
            field_dict["searchParams"] = search_params
        if page_size is not UNSET:
            field_dict["pageSize"] = page_size
        if cursor is not UNSET:
            field_dict["cursor"] = cursor

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.investment_search_body_search_params_type_0 import InvestmentSearchBodySearchParamsType0
        d = dict(src_dict)
        api_key = d.pop("apiKey")

        def _parse_search_params(data: object) -> Union['InvestmentSearchBodySearchParamsType0', None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                search_params_type_0 = InvestmentSearchBodySearchParamsType0.from_dict(data)



                return search_params_type_0
            except: # noqa: E722
                pass
            return cast(Union['InvestmentSearchBodySearchParamsType0', None, Unset], data)

        search_params = _parse_search_params(d.pop("searchParams", UNSET))


        page_size = d.pop("pageSize", UNSET)

        def _parse_cursor(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        cursor = _parse_cursor(d.pop("cursor", UNSET))


        investment_search_body = cls(
            api_key=api_key,
            search_params=search_params,
            page_size=page_size,
            cursor=cursor,
        )


        investment_search_body.additional_properties = d
        return investment_search_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="KitchenSinkBulkProfileResponse200OutputDataItemItemDetailedEducationType0ItemSchoolDetailsType0")



@_attrs_define
class KitchenSinkBulkProfileResponse200OutputDataItemItemDetailedEducationType0ItemSchoolDetailsType0:
    """ 
        Attributes:
            linkedin_ids (Union[None, Unset, list[str]]):
            li_org_id (Union[None, Unset, str]):
            linkedin_primary_slug (Union[None, Unset, str]):
            domains (Union[None, Unset, list[str]]):
            preferred_name (Union[None, Unset, str]):
     """

    linkedin_ids: Union[None, Unset, list[str]] = UNSET
    li_org_id: Union[None, Unset, str] = UNSET
    linkedin_primary_slug: Union[None, Unset, str] = UNSET
    domains: Union[None, Unset, list[str]] = UNSET
    preferred_name: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        linkedin_ids: Union[None, Unset, list[str]]
        if isinstance(self.linkedin_ids, Unset):
            linkedin_ids = UNSET
        elif isinstance(self.linkedin_ids, list):
            linkedin_ids = self.linkedin_ids


        else:
            linkedin_ids = self.linkedin_ids

        li_org_id: Union[None, Unset, str]
        if isinstance(self.li_org_id, Unset):
            li_org_id = UNSET
        else:
            li_org_id = self.li_org_id

        linkedin_primary_slug: Union[None, Unset, str]
        if isinstance(self.linkedin_primary_slug, Unset):
            linkedin_primary_slug = UNSET
        else:
            linkedin_primary_slug = self.linkedin_primary_slug

        domains: Union[None, Unset, list[str]]
        if isinstance(self.domains, Unset):
            domains = UNSET
        elif isinstance(self.domains, list):
            domains = self.domains


        else:
            domains = self.domains

        preferred_name: Union[None, Unset, str]
        if isinstance(self.preferred_name, Unset):
            preferred_name = UNSET
        else:
            preferred_name = self.preferred_name


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if linkedin_ids is not UNSET:
            field_dict["linkedin_ids"] = linkedin_ids
        if li_org_id is not UNSET:
            field_dict["li_org_id"] = li_org_id
        if linkedin_primary_slug is not UNSET:
            field_dict["linkedin_primary_slug"] = linkedin_primary_slug
        if domains is not UNSET:
            field_dict["domains"] = domains
        if preferred_name is not UNSET:
            field_dict["preferred_name"] = preferred_name

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_linkedin_ids(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                linkedin_ids_type_0 = cast(list[str], data)

                return linkedin_ids_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        linkedin_ids = _parse_linkedin_ids(d.pop("linkedin_ids", UNSET))


        def _parse_li_org_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        li_org_id = _parse_li_org_id(d.pop("li_org_id", UNSET))


        def _parse_linkedin_primary_slug(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        linkedin_primary_slug = _parse_linkedin_primary_slug(d.pop("linkedin_primary_slug", UNSET))


        def _parse_domains(data: object) -> Union[None, Unset, list[str]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                domains_type_0 = cast(list[str], data)

                return domains_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[str]], data)

        domains = _parse_domains(d.pop("domains", UNSET))


        def _parse_preferred_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        preferred_name = _parse_preferred_name(d.pop("preferred_name", UNSET))


        kitchen_sink_bulk_profile_response_200_output_data_item_item_detailed_education_type_0_item_school_details_type_0 = cls(
            linkedin_ids=linkedin_ids,
            li_org_id=li_org_id,
            linkedin_primary_slug=linkedin_primary_slug,
            domains=domains,
            preferred_name=preferred_name,
        )


        kitchen_sink_bulk_profile_response_200_output_data_item_item_detailed_education_type_0_item_school_details_type_0.additional_properties = d
        return kitchen_sink_bulk_profile_response_200_output_data_item_item_detailed_education_type_0_item_school_details_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class SyncCombinedSearchBodyCompanyParamsExactCompanyV2Type0NoneOfType0ItemType3SourceType2Type1(str, Enum):
    CSV = "csv"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.company_count_body_search_params_crunchbase_categories_type_0_all_of_type_0_item_type import CompanyCountBodySearchParamsCrunchbaseCategoriesType0AllOfType0ItemType






T = TypeVar("T", bound="CompanyCountBodySearchParamsCrunchbaseCategoriesType0AllOfType0Item")



@_attrs_define
class CompanyCountBodySearchParamsCrunchbaseCategoriesType0AllOfType0Item:
    """ 
        Attributes:
            group (str):
            category (str):
            type_ (CompanyCountBodySearchParamsCrunchbaseCategoriesType0AllOfType0ItemType):
     """

    group: str
    category: str
    type_: CompanyCountBodySearchParamsCrunchbaseCategoriesType0AllOfType0ItemType
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        group = self.group

        category = self.category

        type_ = self.type_.value


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "group": group,
            "category": category,
            "type": type_,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        group = d.pop("group")

        category = d.pop("category")

        type_ = CompanyCountBodySearchParamsCrunchbaseCategoriesType0AllOfType0ItemType(d.pop("type"))




        company_count_body_search_params_crunchbase_categories_type_0_all_of_type_0_item = cls(
            group=group,
            category=category,
            type_=type_,
        )


        company_count_body_search_params_crunchbase_categories_type_0_all_of_type_0_item.additional_properties = d
        return company_count_body_search_params_crunchbase_categories_type_0_all_of_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class KitchenSinkCompanyResponse200OutputDataItemRoleCountMatchesType0ItemNumMatchingEmployeesType0Type(str, Enum):
    EXACT = "exact"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="GetCurrentProfilesInSavedSearchResponse200OutputProfilesItemProjectsType0Item")



@_attrs_define
class GetCurrentProfilesInSavedSearchResponse200OutputProfilesItemProjectsType0Item:
    """ 
        Attributes:
            project_id (Union[None, Unset, str]):
            project_title (Union[None, Unset, str]):
            project_url (Union[None, Unset, str]):
            project_summary (Union[None, Unset, str]):
            is_current (Union[None, Unset, bool]):
            start_date (Union[None, Unset, str]):
            end_date (Union[None, Unset, str]):
     """

    project_id: Union[None, Unset, str] = UNSET
    project_title: Union[None, Unset, str] = UNSET
    project_url: Union[None, Unset, str] = UNSET
    project_summary: Union[None, Unset, str] = UNSET
    is_current: Union[None, Unset, bool] = UNSET
    start_date: Union[None, Unset, str] = UNSET
    end_date: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        project_id: Union[None, Unset, str]
        if isinstance(self.project_id, Unset):
            project_id = UNSET
        else:
            project_id = self.project_id

        project_title: Union[None, Unset, str]
        if isinstance(self.project_title, Unset):
            project_title = UNSET
        else:
            project_title = self.project_title

        project_url: Union[None, Unset, str]
        if isinstance(self.project_url, Unset):
            project_url = UNSET
        else:
            project_url = self.project_url

        project_summary: Union[None, Unset, str]
        if isinstance(self.project_summary, Unset):
            project_summary = UNSET
        else:
            project_summary = self.project_summary

        is_current: Union[None, Unset, bool]
        if isinstance(self.is_current, Unset):
            is_current = UNSET
        else:
            is_current = self.is_current

        start_date: Union[None, Unset, str]
        if isinstance(self.start_date, Unset):
            start_date = UNSET
        else:
            start_date = self.start_date

        end_date: Union[None, Unset, str]
        if isinstance(self.end_date, Unset):
            end_date = UNSET
        else:
            end_date = self.end_date


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if project_id is not UNSET:
            field_dict["project_id"] = project_id
        if project_title is not UNSET:
            field_dict["project_title"] = project_title
        if project_url is not UNSET:
            field_dict["project_url"] = project_url
        if project_summary is not UNSET:
            field_dict["project_summary"] = project_summary
        if is_current is not UNSET:
            field_dict["is_current"] = is_current
        if start_date is not UNSET:
            field_dict["start_date"] = start_date
        if end_date is not UNSET:
            field_dict["end_date"] = end_date

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        def _parse_project_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        project_id = _parse_project_id(d.pop("project_id", UNSET))


        def _parse_project_title(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        project_title = _parse_project_title(d.pop("project_title", UNSET))


        def _parse_project_url(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        project_url = _parse_project_url(d.pop("project_url", UNSET))


        def _parse_project_summary(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        project_summary = _parse_project_summary(d.pop("project_summary", UNSET))


        def _parse_is_current(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        is_current = _parse_is_current(d.pop("is_current", UNSET))


        def _parse_start_date(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        start_date = _parse_start_date(d.pop("start_date", UNSET))


        def _parse_end_date(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        end_date = _parse_end_date(d.pop("end_date", UNSET))


        get_current_profiles_in_saved_search_response_200_output_profiles_item_projects_type_0_item = cls(
            project_id=project_id,
            project_title=project_title,
            project_url=project_url,
            project_summary=project_summary,
            is_current=is_current,
            start_date=start_date,
            end_date=end_date,
        )


        get_current_profiles_in_saved_search_response_200_output_profiles_item_projects_type_0_item.additional_properties = d
        return get_current_profiles_in_saved_search_response_200_output_profiles_item_projects_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="TextToCombinedSearchResponse200OutputDataCompaniesItemLiIndustriesType0Item")



@_attrs_define
class TextToCombinedSearchResponse200OutputDataCompaniesItemLiIndustriesType0Item:
    """ 
        Attributes:
            id (str):
            name (str):
            primary (Union[None, Unset, bool]):
     """

    id: str
    name: str
    primary: Union[None, Unset, bool] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        id = self.id

        name = self.name

        primary: Union[None, Unset, bool]
        if isinstance(self.primary, Unset):
            primary = UNSET
        else:
            primary = self.primary


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "id": id,
            "name": name,
        })
        if primary is not UNSET:
            field_dict["primary"] = primary

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        id = d.pop("id")

        name = d.pop("name")

        def _parse_primary(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        primary = _parse_primary(d.pop("primary", UNSET))


        text_to_combined_search_response_200_output_data_companies_item_li_industries_type_0_item = cls(
            id=id,
            name=name,
            primary=primary,
        )


        text_to_combined_search_response_200_output_data_companies_item_li_industries_type_0_item.additional_properties = d
        return text_to_combined_search_response_200_output_data_companies_item_li_industries_type_0_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.company_search_body_search_params_technologies_type_0_none_of_type_0_item_type_1_type import CompanySearchBodySearchParamsTechnologiesType0NoneOfType0ItemType1Type






T = TypeVar("T", bound="CompanySearchBodySearchParamsTechnologiesType0NoneOfType0ItemType1")



@_attrs_define
class CompanySearchBodySearchParamsTechnologiesType0NoneOfType0ItemType1:
    """ 
        Attributes:
            type_ (CompanySearchBodySearchParamsTechnologiesType0NoneOfType0ItemType1Type):
            name (str):
     """

    type_: CompanySearchBodySearchParamsTechnologiesType0NoneOfType0ItemType1Type
    name: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_.value

        name = self.name


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "name": name,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = CompanySearchBodySearchParamsTechnologiesType0NoneOfType0ItemType1Type(d.pop("type"))




        name = d.pop("name")

        company_search_body_search_params_technologies_type_0_none_of_type_0_item_type_1 = cls(
            type_=type_,
            name=name,
        )


        company_search_body_search_params_technologies_type_0_none_of_type_0_item_type_1.additional_properties = d
        return company_search_body_search_params_technologies_type_0_none_of_type_0_item_type_1

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="GetExcludedCompaniesForExclusionListBody")



@_attrs_define
class GetExcludedCompaniesForExclusionListBody:
    """ 
        Attributes:
            api_key (str): Your Fiber API key
            exclusion_list_id (str): ID of the company exclusion list
            cursor (Union[None, Unset, str]): Pagination cursor
            page_size (Union[Unset, int]): Number of companies to return per page Default: 25.
     """

    api_key: str
    exclusion_list_id: str
    cursor: Union[None, Unset, str] = UNSET
    page_size: Union[Unset, int] = 25
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        api_key = self.api_key

        exclusion_list_id = self.exclusion_list_id

        cursor: Union[None, Unset, str]
        if isinstance(self.cursor, Unset):
            cursor = UNSET
        else:
            cursor = self.cursor

        page_size = self.page_size


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "apiKey": api_key,
            "exclusionListId": exclusion_list_id,
        })
        if cursor is not UNSET:
            field_dict["cursor"] = cursor
        if page_size is not UNSET:
            field_dict["pageSize"] = page_size

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        api_key = d.pop("apiKey")

        exclusion_list_id = d.pop("exclusionListId")

        def _parse_cursor(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        cursor = _parse_cursor(d.pop("cursor", UNSET))


        page_size = d.pop("pageSize", UNSET)

        get_excluded_companies_for_exclusion_list_body = cls(
            api_key=api_key,
            exclusion_list_id=exclusion_list_id,
            cursor=cursor,
            page_size=page_size,
        )


        get_excluded_companies_for_exclusion_list_body.additional_properties = d
        return get_excluded_companies_for_exclusion_list_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import IntEnum

class TextToCompanySearchParamsResponse200OutputSearchParamsEmployeeCountV2Type0UpperBoundInclusiveType1(IntEnum):
    VALUE_1 = 1

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class CreateSavedSearchBodySearchParamsType0ProfileSearchParamsJobTitleV3Type0AnyOfType0ItemType0Type(str, Enum):
    PLAIN = "plain"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Union

if TYPE_CHECKING:
  from ..models.company_search_body_search_params_exact_company_v2_type_0_none_of_type_0_item_type_3 import CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType3
  from ..models.company_search_body_search_params_exact_company_v2_type_0_any_of_type_0_item_type_0 import CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType0
  from ..models.company_search_body_search_params_exact_company_v2_type_0_none_of_type_0_item_type_0 import CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType0
  from ..models.company_search_body_search_params_exact_company_v2_type_0_none_of_type_0_item_type_2 import CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType2
  from ..models.company_search_body_search_params_exact_company_v2_type_0_none_of_type_0_item_type_1 import CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType1
  from ..models.company_search_body_search_params_exact_company_v2_type_0_any_of_type_0_item_type_3 import CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType3
  from ..models.company_search_body_search_params_exact_company_v2_type_0_any_of_type_0_item_type_1 import CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType1
  from ..models.company_search_body_search_params_exact_company_v2_type_0_any_of_type_0_item_type_2 import CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType2





T = TypeVar("T", bound="CompanySearchBodySearchParamsExactCompanyV2Type0")



@_attrs_define
class CompanySearchBodySearchParamsExactCompanyV2Type0:
    """ 
        Attributes:
            any_of (Union[None, Unset, list[Union['CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType0',
                'CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType1',
                'CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType2',
                'CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType3']]]):
            none_of (Union[None, Unset, list[Union['CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType0',
                'CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType1',
                'CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType2',
                'CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType3']]]):
     """

    any_of: Union[None, Unset, list[Union['CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType0', 'CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType1', 'CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType2', 'CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType3']]] = UNSET
    none_of: Union[None, Unset, list[Union['CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType0', 'CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType1', 'CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType2', 'CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType3']]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.company_search_body_search_params_exact_company_v2_type_0_none_of_type_0_item_type_3 import CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType3
        from ..models.company_search_body_search_params_exact_company_v2_type_0_any_of_type_0_item_type_0 import CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType0
        from ..models.company_search_body_search_params_exact_company_v2_type_0_none_of_type_0_item_type_0 import CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType0
        from ..models.company_search_body_search_params_exact_company_v2_type_0_none_of_type_0_item_type_2 import CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType2
        from ..models.company_search_body_search_params_exact_company_v2_type_0_none_of_type_0_item_type_1 import CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType1
        from ..models.company_search_body_search_params_exact_company_v2_type_0_any_of_type_0_item_type_3 import CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType3
        from ..models.company_search_body_search_params_exact_company_v2_type_0_any_of_type_0_item_type_1 import CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType1
        from ..models.company_search_body_search_params_exact_company_v2_type_0_any_of_type_0_item_type_2 import CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType2
        any_of: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.any_of, Unset):
            any_of = UNSET
        elif isinstance(self.any_of, list):
            any_of = []
            for any_of_type_0_item_data in self.any_of:
                any_of_type_0_item: dict[str, Any]
                if isinstance(any_of_type_0_item_data, CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType0):
                    any_of_type_0_item = any_of_type_0_item_data.to_dict()
                elif isinstance(any_of_type_0_item_data, CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType1):
                    any_of_type_0_item = any_of_type_0_item_data.to_dict()
                elif isinstance(any_of_type_0_item_data, CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType2):
                    any_of_type_0_item = any_of_type_0_item_data.to_dict()
                else:
                    any_of_type_0_item = any_of_type_0_item_data.to_dict()

                any_of.append(any_of_type_0_item)


        else:
            any_of = self.any_of

        none_of: Union[None, Unset, list[dict[str, Any]]]
        if isinstance(self.none_of, Unset):
            none_of = UNSET
        elif isinstance(self.none_of, list):
            none_of = []
            for none_of_type_0_item_data in self.none_of:
                none_of_type_0_item: dict[str, Any]
                if isinstance(none_of_type_0_item_data, CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType0):
                    none_of_type_0_item = none_of_type_0_item_data.to_dict()
                elif isinstance(none_of_type_0_item_data, CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType1):
                    none_of_type_0_item = none_of_type_0_item_data.to_dict()
                elif isinstance(none_of_type_0_item_data, CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType2):
                    none_of_type_0_item = none_of_type_0_item_data.to_dict()
                else:
                    none_of_type_0_item = none_of_type_0_item_data.to_dict()

                none_of.append(none_of_type_0_item)


        else:
            none_of = self.none_of


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
        })
        if any_of is not UNSET:
            field_dict["anyOf"] = any_of
        if none_of is not UNSET:
            field_dict["noneOf"] = none_of

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.company_search_body_search_params_exact_company_v2_type_0_none_of_type_0_item_type_3 import CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType3
        from ..models.company_search_body_search_params_exact_company_v2_type_0_any_of_type_0_item_type_0 import CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType0
        from ..models.company_search_body_search_params_exact_company_v2_type_0_none_of_type_0_item_type_0 import CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType0
        from ..models.company_search_body_search_params_exact_company_v2_type_0_none_of_type_0_item_type_2 import CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType2
        from ..models.company_search_body_search_params_exact_company_v2_type_0_none_of_type_0_item_type_1 import CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType1
        from ..models.company_search_body_search_params_exact_company_v2_type_0_any_of_type_0_item_type_3 import CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType3
        from ..models.company_search_body_search_params_exact_company_v2_type_0_any_of_type_0_item_type_1 import CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType1
        from ..models.company_search_body_search_params_exact_company_v2_type_0_any_of_type_0_item_type_2 import CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType2
        d = dict(src_dict)
        def _parse_any_of(data: object) -> Union[None, Unset, list[Union['CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType0', 'CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType1', 'CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType2', 'CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType3']]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                any_of_type_0 = []
                _any_of_type_0 = data
                for any_of_type_0_item_data in (_any_of_type_0):
                    def _parse_any_of_type_0_item(data: object) -> Union['CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType0', 'CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType1', 'CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType2', 'CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType3']:
                        try:
                            if not isinstance(data, dict):
                                raise TypeError()
                            any_of_type_0_item_type_0 = CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType0.from_dict(data)



                            return any_of_type_0_item_type_0
                        except: # noqa: E722
                            pass
                        try:
                            if not isinstance(data, dict):
                                raise TypeError()
                            any_of_type_0_item_type_1 = CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType1.from_dict(data)



                            return any_of_type_0_item_type_1
                        except: # noqa: E722
                            pass
                        try:
                            if not isinstance(data, dict):
                                raise TypeError()
                            any_of_type_0_item_type_2 = CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType2.from_dict(data)



                            return any_of_type_0_item_type_2
                        except: # noqa: E722
                            pass
                        if not isinstance(data, dict):
                            raise TypeError()
                        any_of_type_0_item_type_3 = CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType3.from_dict(data)



                        return any_of_type_0_item_type_3

                    any_of_type_0_item = _parse_any_of_type_0_item(any_of_type_0_item_data)

                    any_of_type_0.append(any_of_type_0_item)

                return any_of_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[Union['CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType0', 'CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType1', 'CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType2', 'CompanySearchBodySearchParamsExactCompanyV2Type0AnyOfType0ItemType3']]], data)

        any_of = _parse_any_of(d.pop("anyOf", UNSET))


        def _parse_none_of(data: object) -> Union[None, Unset, list[Union['CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType0', 'CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType1', 'CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType2', 'CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType3']]]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                none_of_type_0 = []
                _none_of_type_0 = data
                for none_of_type_0_item_data in (_none_of_type_0):
                    def _parse_none_of_type_0_item(data: object) -> Union['CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType0', 'CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType1', 'CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType2', 'CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType3']:
                        try:
                            if not isinstance(data, dict):
                                raise TypeError()
                            none_of_type_0_item_type_0 = CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType0.from_dict(data)



                            return none_of_type_0_item_type_0
                        except: # noqa: E722
                            pass
                        try:
                            if not isinstance(data, dict):
                                raise TypeError()
                            none_of_type_0_item_type_1 = CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType1.from_dict(data)



                            return none_of_type_0_item_type_1
                        except: # noqa: E722
                            pass
                        try:
                            if not isinstance(data, dict):
                                raise TypeError()
                            none_of_type_0_item_type_2 = CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType2.from_dict(data)



                            return none_of_type_0_item_type_2
                        except: # noqa: E722
                            pass
                        if not isinstance(data, dict):
                            raise TypeError()
                        none_of_type_0_item_type_3 = CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType3.from_dict(data)



                        return none_of_type_0_item_type_3

                    none_of_type_0_item = _parse_none_of_type_0_item(none_of_type_0_item_data)

                    none_of_type_0.append(none_of_type_0_item)

                return none_of_type_0
            except: # noqa: E722
                pass
            return cast(Union[None, Unset, list[Union['CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType0', 'CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType1', 'CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType2', 'CompanySearchBodySearchParamsExactCompanyV2Type0NoneOfType0ItemType3']]], data)

        none_of = _parse_none_of(d.pop("noneOf", UNSET))


        company_search_body_search_params_exact_company_v2_type_0 = cls(
            any_of=any_of,
            none_of=none_of,
        )


        company_search_body_search_params_exact_company_v2_type_0.additional_properties = d
        return company_search_body_search_params_exact_company_v2_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CreateSavedSearchBodySearchParamsType2ProfileSearchParamsJobTitleV2Type0AnyOfType0ItemType0Type(str, Enum):
    TERM = "term"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum

class CompanySearchBodySearchParamsJobPostingStatsType0AllOfType0ItemType2Rule(str, Enum):
    SENIORITY = "seniority"

    def __str__(self) -> str:
        return str(self.value)



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset







T = TypeVar("T", bound="CombinedSearchBodyProfileParamsStealthV2Type1StealthDurationType0Range")



@_attrs_define
class CombinedSearchBodyProfileParamsStealthV2Type1StealthDurationType0Range:
    """ 
        Attributes:
            lower_bound (float):
            upper_bound (float):
     """

    lower_bound: float
    upper_bound: float
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        lower_bound = self.lower_bound

        upper_bound = self.upper_bound


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "lowerBound": lower_bound,
            "upperBound": upper_bound,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        lower_bound = d.pop("lowerBound")

        upper_bound = d.pop("upperBound")

        combined_search_body_profile_params_stealth_v2_type_1_stealth_duration_type_0_range = cls(
            lower_bound=lower_bound,
            upper_bound=upper_bound,
        )


        combined_search_body_profile_params_stealth_v2_type_1_stealth_duration_type_0_range.additional_properties = d
        return combined_search_body_profile_params_stealth_v2_type_1_stealth_duration_type_0_range

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.bulk_company_logos_response_200_output_data_type_0_type import BulkCompanyLogosResponse200OutputDataType0Type
from typing import cast

if TYPE_CHECKING:
  from ..models.bulk_company_logos_response_200_output_data_type_0_data_item import BulkCompanyLogosResponse200OutputDataType0DataItem





T = TypeVar("T", bound="BulkCompanyLogosResponse200OutputDataType0")



@_attrs_define
class BulkCompanyLogosResponse200OutputDataType0:
    """ 
        Attributes:
            type_ (BulkCompanyLogosResponse200OutputDataType0Type):
            data (list['BulkCompanyLogosResponse200OutputDataType0DataItem']):
     """

    type_: BulkCompanyLogosResponse200OutputDataType0Type
    data: list['BulkCompanyLogosResponse200OutputDataType0DataItem']
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.bulk_company_logos_response_200_output_data_type_0_data_item import BulkCompanyLogosResponse200OutputDataType0DataItem
        type_ = self.type_.value

        data = []
        for data_item_data in self.data:
            data_item = data_item_data.to_dict()
            data.append(data_item)




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "data": data,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.bulk_company_logos_response_200_output_data_type_0_data_item import BulkCompanyLogosResponse200OutputDataType0DataItem
        d = dict(src_dict)
        type_ = BulkCompanyLogosResponse200OutputDataType0Type(d.pop("type"))




        data = []
        _data = d.pop("data")
        for data_item_data in (_data):
            data_item = BulkCompanyLogosResponse200OutputDataType0DataItem.from_dict(data_item_data)



            data.append(data_item)


        bulk_company_logos_response_200_output_data_type_0 = cls(
            type_=type_,
            data=data,
        )


        bulk_company_logos_response_200_output_data_type_0.additional_properties = d
        return bulk_company_logos_response_200_output_data_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from collections.abc import Mapping
from typing import Any, TypeVar, Optional, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast, Union
from typing import Union






T = TypeVar("T", bound="ProfileReactionsLiveFetchBody")



@_attrs_define
class ProfileReactionsLiveFetchBody:
    """ 
        Attributes:
            api_key (str): Your Fiber API key
            identifier (str): Identifier can be a profile's LinkedIn slug (e.g. 'williamhgates' from
                <linkedin.com/in/williamhgates>), a Sales Navigator URN (e.g. 'ACwAAA.....'), or a full LinkedIn URL (e.g.
                'https://www.linkedin.com/in/williamhgates/')
            cursor (Union[None, Unset, str]): Pagination cursor for fetching additional pages of reactions
     """

    api_key: str
    identifier: str
    cursor: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        api_key = self.api_key

        identifier = self.identifier

        cursor: Union[None, Unset, str]
        if isinstance(self.cursor, Unset):
            cursor = UNSET
        else:
            cursor = self.cursor


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "apiKey": api_key,
            "identifier": identifier,
        })
        if cursor is not UNSET:
            field_dict["cursor"] = cursor

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        api_key = d.pop("apiKey")

        identifier = d.pop("identifier")

        def _parse_cursor(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        cursor = _parse_cursor(d.pop("cursor", UNSET))


        profile_reactions_live_fetch_body = cls(
            api_key=api_key,
            identifier=identifier,
            cursor=cursor,
        )


        profile_reactions_live_fetch_body.additional_properties = d
        return profile_reactions_live_fetch_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class CreateSavedSearchBodySearchParamsType0ProfileSearchParamsStealthV2Type0EnteredStealthAtType1WindowType1Period(str, Enum):
    DAY = "day"
    MONTH = "month"
    QUARTER = "quarter"
    WEEK = "week"
    YEAR = "year"

    def __str__(self) -> str:
        return str(self.value)
